package view;

import javafx.scene.effect.Glow;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.AnchorPane;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;

public class HUD {

    private Image standard_img, variant_img, rollback_img;
    private ImageView standard_imgView, variant_imgView, rollback_imgView;
    private Rectangle darkener;

    public HUD() {
        standard_img = new Image("/standard.jpg");
        variant_img = new Image("/variant.jpg");
        standard_imgView = new ImageView(standard_img);
        variant_imgView = new ImageView(variant_img);
        standard_imgView.setPreserveRatio(true);
        variant_imgView.setPreserveRatio(true);
        darkener = new Rectangle();
        darkener.setX(0);
        darkener.setY(0);
        darkener.setFill(Color.BLACK);
        darkener.setOpacity(0.5);
        Glow glow = new Glow(0.2);
        Glow none = new Glow(0);
        standard_imgView.addEventHandler(MouseEvent.MOUSE_ENTERED, event -> {
            standard_imgView.setEffect(glow);
            variant_imgView.setEffect(none);
        });
        standard_imgView.addEventHandler(MouseEvent.MOUSE_EXITED, event -> {
            standard_imgView.setEffect(none);
        });
        variant_imgView.addEventHandler(MouseEvent.MOUSE_ENTERED, event -> {
            variant_imgView.setEffect(glow);
        });
        variant_imgView.addEventHandler(MouseEvent.MOUSE_EXITED, event -> {
            variant_imgView.setEffect(none);
        });
        rollback_img = new Image("/rollback.png");
        rollback_imgView = new ImageView(rollback_img);
        rollback_imgView.setPreserveRatio(true);
        rollback_imgView.setFitWidth(64);
        rollbackHide();
    }

    public void resize(double width, double height) {
        int weight = 2;
        int total = weight*2 + 4;
        standard_imgView.setX(width/total);
        standard_imgView.setY(height/total/2);
        standard_imgView.setFitWidth(width*weight/total);
        variant_imgView.setX(width/total * (weight+3));
        variant_imgView.setY(height/total/2);
        variant_imgView.setFitWidth(width*weight/total);
        darkener.setWidth(width);
        darkener.setHeight(height);
        rollback_imgView.setX(width - 100);
        rollback_imgView.setY(height - 120);
    }

    public ImageView getStandard() {
        return standard_imgView;
    }

    public ImageView getVariant() {
        return variant_imgView;
    }

    public ImageView getRollback() {
        return rollback_imgView;
    }

    public void rollbackHide() {
        rollback_imgView.setOpacity(0);
    }
    public void rollbackShow() {
        rollback_imgView.setOpacity(1);
    }

    public void removeMenu(AnchorPane group2d) {
        group2d.getChildren().removeAll(darkener, standard_imgView, variant_imgView);
    }
    public void addAllToScene(AnchorPane group2d) {
        group2d.getChildren().addAll(darkener, standard_imgView, variant_imgView, rollback_imgView);
    }
}
